@@ -14,11 +14,11 @@ Genealogy::ObituaryDailyTimes - Compare a Gedcom against the Obituary Daily Time
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -57,7 +57,7 @@ sub new {
 
    my @smiths = $obits->search(last => 'Smith');
 
-   print $smiths[0]->{'first'}, "\n';
+   print $smiths[0]->{'first'}, "\n";
 
 =cut
 
